@@ -1,8 +1,11 @@
-from cms.plugin_base import CMSPluginBase
 from cms.plugin_pool import plugin_pool
 from django.utils.translation import gettext_lazy as _
 
 from ... import settings
+from ...cms_plugins import CMSUIPlugin
+from ...common.attributes import AttributesMixin
+from ...common.responsive import ResponsiveMixin
+from ...common.spacing import SpacingMixin
 from .. import alert
 from . import forms, models
 
@@ -10,7 +13,9 @@ mixin_factory = settings.get_renderer(alert)
 
 
 @plugin_pool.register_plugin
-class AlertPlugin(mixin_factory("Alert"), CMSPluginBase):
+class AlertPlugin(
+    mixin_factory("Alert"), AttributesMixin, ResponsiveMixin, SpacingMixin, CMSUIPlugin
+):
     """
     Components > "Alerts" Plugin
     https://getbootstrap.com/docs/5.0/components/alerts/
@@ -20,7 +25,6 @@ class AlertPlugin(mixin_factory("Alert"), CMSPluginBase):
     module = _("Frontend")
     model = models.Alert
     form = forms.AlertForm
-    render_template = f"djangocms_frontend/{settings.framework}/alert.html"
     change_form_template = "djangocms_frontend/admin/alert.html"
     allow_children = True
 
@@ -34,14 +38,4 @@ class AlertPlugin(mixin_factory("Alert"), CMSPluginBase):
                 ]
             },
         ),
-        (
-            _("Advanced settings"),
-            {
-                "classes": ("collapse",),
-                "fields": (
-                    "tag_type",
-                    "attributes",
-                ),
-            },
-        ),
     ]
