@@ -6,29 +6,28 @@ class LinkRenderMixin:
             link_classes.append("list-group-item-action")
             background_prefix = "list-group-item"
         elif (
-            instance.link_type == "link"
+            getattr(instance, "link_type", "link") == "link"
             and instance.parent
             and instance.parent.plugin_type == "CardInnerPlugin"
         ):
             link_classes.append("card-link")
         else:
             background_prefix = "btn"
-        if instance.link_context:
-            if instance.link_type == "link":
-                link_classes.append("text-{}".format(instance.link_context))
+        if instance.config.get("link_context", None):
+            if getattr(instance, "link_type", "link") == "link":
+                link_classes.append(f"link-{instance.link_context}")
             else:
                 link_classes.append("btn")
                 if not instance.link_outline:
-                    link_classes.append(
-                        "{}-{}".format(background_prefix, instance.link_context)
-                    )
+                    link_classes.append(f"{background_prefix}-{instance.link_context}")
                 else:
-                    link_classes.append("btn-outline-{}".format(instance.link_context))
-        if instance.link_size:
+                    link_classes.append(f"btn-outline-{instance.link_context}")
+        if instance.config.get("link_size", False):
             link_classes.append(instance.link_size)
-        if instance.link_block:
-            link_classes.append("btn-block")
-
+        if instance.config.get("link_block", False):
+            link_classes.append("d-block")
+        if instance.config.get("link_stretched", False):
+            link_classes.append("stretched-link")
         context["link"] = instance.get_link()
         instance.add_classes(link_classes)
         return super().render(context, instance, placeholder)
